==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/EMRSCLASS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EMRSCLASS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EMRSCLASS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSSTRUCTURECODEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMRSCLASS_Type", propOrder = {
    "vmrsstructurecodeid",
    "classid",
    "entityid"
})
public class EMRSCLASS_Type {

    @XmlElement(name = "VMRSSTRUCTURECODEID", required = true)
    protected VMRSSTRUCTURECODEID vmrsstructurecodeid;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "ENTITYID", required = true)
    protected ENTITYID_Type entityid;

    /**
     * Obtient la valeur de la propriété vmrsstructurecodeid.
     * 
     * @return
     *     possible object is
     *     {@link VMRSSTRUCTURECODEID }
     *     
     */
    public VMRSSTRUCTURECODEID getVMRSSTRUCTURECODEID() {
        return vmrsstructurecodeid;
    }

    /**
     * Définit la valeur de la propriété vmrsstructurecodeid.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSSTRUCTURECODEID }
     *     
     */
    public void setVMRSSTRUCTURECODEID(VMRSSTRUCTURECODEID value) {
        this.vmrsstructurecodeid = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété entityid.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Définit la valeur de la propriété entityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/EMRSCLASS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EMRSCLASS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EMRSCLASS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VMRSSTRUCTURECODEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EMRSCLASS_Type", propOrder = {
    "vmrsstructurecodeid",
    "classid",
    "entityid"
})
public class EMRSCLASS_Type {

    @XmlElement(name = "VMRSSTRUCTURECODEID", required = true)
    protected VMRSSTRUCTURECODEID vmrsstructurecodeid;
    @XmlElement(name = "CLASSID", required = true)
    protected CLASSID_Type classid;
    @XmlElement(name = "ENTITYID", required = true)
    protected ENTITYID_Type entityid;

    /**
     * Gets the value of the vmrsstructurecodeid property.
     * 
     * @return
     *     possible object is
     *     {@link VMRSSTRUCTURECODEID }
     *     
     */
    public VMRSSTRUCTURECODEID getVMRSSTRUCTURECODEID() {
        return vmrsstructurecodeid;
    }

    /**
     * Sets the value of the vmrsstructurecodeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link VMRSSTRUCTURECODEID }
     *     
     */
    public void setVMRSSTRUCTURECODEID(VMRSSTRUCTURECODEID value) {
        this.vmrsstructurecodeid = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the entityid property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Sets the value of the entityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

}
